[__all__]: https://docs.python.org/3/tutorial/modules.html#importing-from-a-package
[class template]: https://github.com/mkdocstrings/python/blob/master/src/mkdocstrings_handlers/python/templates/material/_base/class.html
[function template]: https://github.com/mkdocstrings/python/blob/master/src/mkdocstrings_handlers/python/templates/material/_base/function.html
[autodoc syntax]: https://mkdocstrings.github.io/usage/#autodoc-syntax
[autopages recipe]: https://mkdocstrings.github.io/recipes/#automatic-code-reference-pages
[Griffe]: https://github.com/mkdocstrings/griffe
[ReadTheDocs Sphinx theme]: https://sphinx-rtd-theme.readthedocs.io/en/stable/index.html
[Spacy's documentation]: https://spacy.io/api/doc/
[Black]: https://pypi.org/project/black/
[Material for MkDocs]: https://squidfunk.github.io/mkdocs-material
[Ruff]: https://docs.astral.sh/ruff

*[ToC]: Table of Contents
